@@ -5,6 +5,7 @@ They are invoked from cli/pycompss.py and uses core/cmd.py.
 
 from pycompss_cli.core.actions import Actions
 from pycompss_cli.core.docker.cmd import DockerCmd
+import pycompss_cli.core.docker.cmd as docker_cmd
 from glob import glob
 import os, traceback
  
@@ -28,6 +29,9 @@ class DockerActions(Actions):
         if self.arguments.working_dir == 'current directory':
             self.arguments.working_dir = os.getcwd()
 
+        
+
+
         try:
             self.docker_cmd.docker_deploy_compss(self.arguments.working_dir,
                                 self.arguments.image,
@@ -93,13 +97,13 @@ class DockerActions(Actions):
         if '--master_name' not in app_args:
             app_args.insert(0, f"--master_name={self.env_conf['master_ip']} ")
         if '--base_log_dir' not in app_args:
-            app_args.insert(0, '--base_log_dir=/home/user ')
+            app_args.insert(0, f'--base_log_dir={docker_cmd.default_workdir} ')
 
         command = "runcompss " + ' '.join(app_args)
 
         self.docker_cmd.docker_exec_in_daemon(command)
 
-        self.docker_cmd.docker_exec_in_daemon('cp -a /home/user/.COMPSs/. /root/.COMPSs/')
+        self.docker_cmd.docker_exec_in_daemon(f'cp -a {docker_cmd.default_workdir}.COMPSs/. /root/.COMPSs/')
 
 
     def monitor(self):
@@ -164,7 +168,7 @@ class DockerActions(Actions):
         self.docker_cmd.docker_exec_in_daemon(command)
 
     def app(self):
-        print("ERROR: Wrong Environment! Try using a `cluster` environment")
+        print("ERROR: Wrong Environment! Try using a `cluster` or `local` environment")
         exit(1)
 
     def components(self):
