@@ -6,6 +6,7 @@ import tempfile
 import shutil
 from uuid import uuid4
 import subprocess
+from pycompss_cli.core import utils
 
 from pycompss_cli.core.cmd_helpers import command_runner
 
@@ -16,12 +17,12 @@ from pycompss_cli.core.cmd_helpers import command_runner
 master_name = "pycompss-master"
 worker_name = "pycompss-worker"
 service_name = "pycompss-service"
-default_workdir = "/home/user/"
-default_worker_workdir = "/home/user/.COMPSsWorker"
+default_workdir = "/home/jenkins/"
+default_worker_workdir = default_workdir + ".COMPSsWorker"
 default_cfg_file = "cfg"
-default_cfg = default_workdir + "/" + default_cfg_file
+default_cfg = default_workdir + default_cfg_file
 default_image_file = "image"
-default_image = default_workdir + "/" + default_image_file
+default_image = default_workdir + default_image_file
 
 
 IMAGE_NAME = "compss/compss:2.10"  # Update when releasing new version
@@ -87,7 +88,8 @@ class DockerCmd(object):
 
     def docker_deploy_compss(self, working_dir,
                             image: str = "",
-                            restart: bool = True) -> None:
+                            restart: bool = True,
+                            extra_mounts: dict = {}) -> None:
         """ Starts the main COMPSs image in Docker.
         It stops any existing one since it can not coexist with itself.
 
@@ -117,7 +119,22 @@ class DockerCmd(object):
                 "while because it needs to download the docker image. " +
                 "Please be patient.")
             subprocess.run(f'docker pull {docker_image}', shell=True)
-            mounts = self._get_mounts(user_working_dir=working_dir)
+
+            inside_docker = utils.is_inside_docker()
+
+            if utils.is_debug():
+                print('\t', '******', 'inside_docker: ', inside_docker)
+
+            if inside_docker:
+                for vol in self.client.volumes.list():
+                    if utils.is_debug():
+                        print('\t', '******', 'volume found: ', vol.name)
+                    if vol.name not in extra_mounts and vol.name == 'JenkinsTestVol':
+                        if utils.is_debug():
+                            print('\t', '******', 'mounting JenkinsTestVol')
+                        extra_mounts[vol.name] = '/home/jenkins/tests_execution_sandbox'
+
+            mounts = self._get_mounts(user_working_dir=working_dir, extra_mounts=extra_mounts)
             ports = {"8888/tcp": 8888,  # required for jupyter notebooks
                     "8080/tcp": 8080}  # required for monitor
             m = self.client.containers.run(image=docker_image, name=master_name,
@@ -371,7 +388,7 @@ class DockerCmd(object):
                 " OF MASTER CONTAINER!!!")
 
 
-    def _get_mounts(self, user_working_dir: str) -> list:
+    def _get_mounts(self, user_working_dir: str, extra_mounts: dict={}) -> list:
         """ Retrieve the list of folders to be mounted. It gets the Mount object
         from the given user working directory, and can include any other needed
         folder.
@@ -384,6 +401,18 @@ class DockerCmd(object):
         user_dir = Mount(target=target_dir,
                         source=user_working_dir,
                         type="bind")
+
+        mounts = [user_dir] if not utils.is_inside_docker() else []
+        for source, target in extra_mounts.items():
+            if utils.is_debug():
+                print('\t', '******', 'Adding extra mount', source, target)
+            mounts.append(Mount(target=target,
+                                source=source,
+                                type="volume"))
+        
+        if utils.is_debug():
+            print('\t', '******', mounts)
+        
         # WARNING: mounting .COMPSs makes it fail
         # compss_logs_dir = os.environ["HOME"] + f"/.COMPSs"
         # os.makedirs(compss_logs_dir, exist_ok=True)
@@ -391,7 +420,7 @@ class DockerCmd(object):
         # compss_log_dir = Mount(target="/root/.COMPSs",
         #                        source=compss_logs_dir,
         #                        type="bind")
-        mounts = [user_dir] #, compss_log_dir]
+         #, compss_log_dir]
         return mounts
 
 
@@ -464,10 +493,10 @@ class DockerCmd(object):
         :param master: Master docker instance object.
         :returns: None
         """
-        exit_code, output = master.exec_run(cmd="rm " + default_cfg)
-        if exit_code != 0:
-            for line in output:
-                print(line.strip().decode())
+        exit_code, output = master.exec_run(cmd="rm -f" + default_cfg)
+        # if exit_code != 0:
+        #     for line in output:
+        #         print(line.strip().decode())
 
 
     def _update_cfg(self, master, cfg: dict, ips, cpus) -> None:
