@@ -64,12 +64,12 @@ def cluster_parser_app():
                              type=str,
                              help="Name of the application")
 
-    app_deploy_parser.add_argument("-ls", "--local_source",
+    app_deploy_parser.add_argument("-s", "--source_dir",
                              default='current directory',
                              type=str,
-                             help="Path from which the files will be copied. Can be a directory or a single file")
+                             help="Directory from which the files will be copied.")
 
-    app_deploy_parser.add_argument("-rd", "--remote_dir",
+    app_deploy_parser.add_argument("-d", "--destination_dir",
                              type=str,
                              help="Remote destination directory to copy the local app files")
 
