@@ -52,4 +52,7 @@ def poll_directory(directory, sleep_time=0.1):
         if new_query != files:
             files = new_query
             yield set(files)
-        time.sleep(sleep_time)
\ No newline at end of file
+        time.sleep(sleep_time)
+
+def is_inside_docker():
+    return ':/docker/' in subprocess.check_output(['cat', '/proc/self/cgroup']).decode('utf-8')
\ No newline at end of file
